import dials_data
import dials_data.datasets
import dials_data.download
from unittest import mock


def test_all_datasets_can_be_parsed():
    assert dials_data.datasets.definition


def test_repository_location():
    rl = dials_data.datasets.repository_location()
    assert rl.check(dir=1)


def test_fetching_undefined_datasets_does_not_crash():
    df = dials_data.download.DataFetcher(read_only=True)
    assert df("aardvark") is False


def test_requests_for_future_datasets_can_be_intercepted():
    df = dials_data.download.DataFetcher(read_only=True)
    df.result_filter = mock.Mock()
    df.result_filter.return_value = False
    assert df("aardvark") is False
    df.result_filter.assert_called_once_with(result=False)



"""
DIALS Regression Data Manager
https://github.com/dials/data
"""

__all__ = []
__author__ = """Markus Gerstel"""
__email__ = "dials-support@lists.sourceforge.net"
__version__ = "2.1.32"
__commit__ = "2a1fdea9aff5889ceef866b5b3c635ec194cee6d"
__version_tuple__ = tuple(int(x) for x in __version__.split("."))
